2D Graphics
===========

General
-------

.. toctree::
   :maxdepth: 1

   sage/plot/plot
   sage/plot/text
   sage/plot/colors
   sage/plot/animate

Function and Data Plots
-----------------------

.. toctree::
   :maxdepth: 1

   sage/plot/complex_plot
   sage/plot/contour_plot
   sage/plot/density_plot
   sage/plot/plot_field
   sage/plot/streamline_plot
   sage/plot/scatter_plot
   sage/plot/step
   sage/plot/histogram
   sage/plot/bar_chart

Plots of Other Mathematical Objects
-----------------------------------

.. toctree::
   :maxdepth: 1

   sage/graphs/graph_plot
   sage/plot/matrix_plot

Basic Shapes
------------

.. toctree::
   :maxdepth: 1

   sage/plot/arc
   sage/plot/arrow
   sage/plot/bezier_path
   sage/plot/circle
   sage/plot/disk
   sage/plot/ellipse
   sage/plot/line
   sage/plot/point
   sage/plot/polygon
   sage/plot/hyperbolic_arc
   sage/plot/hyperbolic_polygon
   sage/plot/hyperbolic_regular_polygon

Infrastructure and Low-Level Functions
--------------------------------------

.. toctree::
   :maxdepth: 1

   sage/plot/graphics
   sage/plot/multigraphics
   sage/plot/primitive
   sage/plot/misc

.. include:: ../footer.txt
